@@ -899,6 +899,11 @@ class S3RegionRedirector(object):
             # transport error.
             return
 
+        if request_dict.get('context', {}).get('s3_redirected'):
+            logger.debug(
+                'S3 request was previously redirected, not redirecting.')
+            return
+
         error = response[1].get('Error', {})
         error_code = error.get('Code')
 
@@ -948,6 +953,8 @@ class S3RegionRedirector(object):
         self._cache[bucket] = signing_context
         self.set_request_url(request_dict, request_dict['context'])
 
+        request_dict['context']['s3_redirected'] = True
+
         # Return 0 so it doesn't wait to retry
         return 0
 
@@ -1013,6 +1020,8 @@ class ContainerMetadataFetcher(object):
     def __init__(self, session=None, sleep=time.sleep):
         if session is None:
             session = requests.Session()
+            session.trust_env = False
+            session.proxies = {}
         self._session = session
         self._sleep = sleep
 
